# What is this directory?

This directory contains materials science workflows that chains together
individual Fireworks defined within atomate. The workflows are defined
in a special YAML format (different than the typical FireWorks format) that
is intended to be simple and easy to modify.

# What is the format of the workflows?

The overall format is YAML. See the online atomate docs for more information.

